@@ -179,23 +179,21 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 	switch (event->keyval) {
 	case GDK_KP_Left:
 	case GDK_Left:
-		if (event->state & GDK_MOD1_MASK){
+		if (event->state & GDK_MOD1_MASK)
 			return TRUE; /* Alt is used for accelerators */
-		}
 
-		if (event->state & SCROLL_LOCK_MASK){
+		if (event->state & SCROLL_LOCK_MASK)
 			scg_set_left_col (scg, pane->first.col - 1);
-		}
 		else if (transition_keys && jump_to_bounds) {
 			delayed_movement = TRUE;
 			scg_queue_movement (scg, movefn,
 				-(pane->last_visible.col - pane->first.col),
 				FALSE, TRUE);
-		}else{
+		} else
 			(*movefn) (scg, sheet->text_is_rtl ? 1 : -1,
 				   jump_to_bounds || end_mode, TRUE);
-		}
 		break;
+
 	case GDK_KP_Right:
 	case GDK_Right:
 		if (event->state & GDK_MOD1_MASK)
@@ -388,23 +386,10 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 			/* For Maemo changed third arg to FALSE in order to avoid bug */
 			blockArrows = TRUE;
 			if (!wbcg_edit_start (wbcg, FALSE, FALSE)){
-				//blockArrows = TRUE;
 				return FALSE; /* attempt to edit failed */
 			}
 		}
-		//else{
-		//	wbcg_edit_finish(wbcg,WBC_EDIT_ACCEPT,NULL);
-		//}
 		break;
-		//if (wbcg_is_editing (wbcg) &&
-		//    (state == GDK_CONTROL_MASK ||
-		//     state == (GDK_CONTROL_MASK|GDK_SHIFT_MASK) ||
-		//     gnumeric_filter_modifiers (event->state) == GDK_MOD1_MASK))
-			/* Forward the keystroke to the input line */
-		//	return gtk_widget_event (
-		//		wbcg_get_entry_underlying (wbcg), (GdkEvent *) event);
-		//is_enter = TRUE;
-		/* fall down */
 
 	case GDK_Tab:
 	case GDK_ISO_Left_Tab:
@@ -447,7 +432,7 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 				if (event->state & GDK_SHIFT_MASK)
 					forward = !forward;
 
-				sv_selection_walk_step2(sv, forward, horizontal);
+				sv_selection_walk_step2 (sv, forward, horizontal);
 
 				/* invalidate, in case Enter direction changes */
 				if (is_enter)
@@ -1081,13 +1066,15 @@ cb_pane_drag_motion (GtkWidget *widget, GdkDragContext *context,
 	if ((IS_GNM_PANE (source_widget) &&
 	     GNM_PANE (source_widget)->simple.scg == scg)) {
 		/* same scg */
-		GnmPane *pane = GNM_PANE (widget);
+		GocCanvas *canvas = GOC_CANVAS (widget);
 		GdkModifierType mask;
 		double wx, wy;
 
 		g_object_set_data (&context->parent_instance,
 			"wbcg", scg_wbcg (scg));
-		goc_canvas_w2c (GOC_CANVAS (pane), x, y, &wx, &wy);
+		goc_canvas_w2c (canvas, x, y, &wx, &wy);
+		wx *= goc_canvas_get_pixels_per_unit (canvas);
+		wy *= goc_canvas_get_pixels_per_unit (canvas);
 
 		gdk_window_get_pointer (gtk_widget_get_parent_window (source_widget),
 			NULL, NULL, &mask);
@@ -2084,6 +2071,9 @@ gnm_pane_size_guide_motion (GnmPane *pane, gboolean vert, gint64 guide_pos)
 static void
 cb_update_ctrl_pts (SheetObject *so, GocItem **ctrl_pts, GnmPane *pane)
 {
+	double *coords = g_hash_table_lookup (
+		pane->simple.scg->selected_objects, so);
+	scg_object_anchor_to_coords (pane->simple.scg, sheet_object_get_anchor (so), coords);
 	gnm_pane_object_update_bbox (pane, so);
 }
 
@@ -2664,14 +2654,14 @@ control_point_button_released (GocItem *item, int button, G_GNUC_UNUSED double x
 		; /* ignore fake event generated by the dnd code */
 	else if (pane->drag.had_motion)
 		scg_objects_drag_commit	(scg, idx,
-			pane->drag.created_objects,
-			NULL, NULL, NULL);
+					 pane->drag.created_objects,
+					 NULL, NULL, NULL);
 	else if (pane->drag.created_objects && idx == 7) {
 		double w, h;
 		sheet_object_default_size (so, &w, &h);
 		scg_objects_drag (scg, NULL, NULL, &w, &h, 7, FALSE, FALSE, FALSE);
 		scg_objects_drag_commit	(scg, 7, TRUE,
-				NULL, NULL, NULL);
+					 NULL, NULL, NULL);
 	}
 	gnm_pane_clear_obj_size_tip (pane);
 	return TRUE;
@@ -2880,7 +2870,8 @@ set_item_x_y (GnmPane *pane, SheetObject *so, GocItem **ctrl_pts,
 	if (ctrl_pts [idx] == NULL)
 		ctrl_pts [idx] = new_control_point (pane, so, idx, x / scale, y / scale, CTRL_PT_SIZE / scale);
 	else
-		goc_item_set (ctrl_pts [idx], "x", x / scale, "y", y / scale, NULL);
+		goc_item_set (ctrl_pts [idx], "x", x / scale, "y", y / scale,
+		              "radius", CTRL_PT_SIZE / scale, NULL);
 	if (visible)
 		goc_item_show (ctrl_pts [idx]);
 	else
@@ -2904,7 +2895,7 @@ set_acetate_coords (GnmPane *pane, SheetObject *so, GocItem **ctrl_pts,
 			style->fill.auto_fore = FALSE;
 			style->fill.pattern.fore = 0;
 			style->line.pattern = GO_PATTERN_THIN_DIAG;
-			style->line.width = 1.;
+			style->line.width = 0.;
 			style->line.auto_color = FALSE;
 			style->line.color = 0;
 			style->line.fore = GO_COLOR_BLACK;
